pub struct JamNodeConfigBuilder<S> { /* private fields */ }Expand description
A node configuration builder, used to build a JamNodeConfig declaratively with fields validation.
Implementations
Sourceimpl JamNodeConfigBuilder<Initial>
impl JamNodeConfigBuilder<Initial>
pub fn new( chain_context: ChainDefaultContext, validation_context: Rc<RefCell<ValidationContext>>, ) -> Self
Sourceimpl JamNodeConfigBuilder<Buildable>
impl JamNodeConfigBuilder<Buildable>
Sourcepub fn with_command<T>(self, command: T) -> Self
pub fn with_command<T>(self, command: T) -> Self
Set the command that will be executed to launch the node. Override the default.
Sourcepub fn with_subcommand<T>(self, subcommand: T) -> Self
pub fn with_subcommand<T>(self, subcommand: T) -> Self
Set the subcommand that will be executed to launch the node.
Sourcepub fn with_image<T>(self, image: T) -> Self
pub fn with_image<T>(self, image: T) -> Self
Set the image that will be used for the node (only podman/k8s). Override the default.
Sourcepub fn with_args(self, args: Vec<Arg>) -> Self
pub fn with_args(self, args: Vec<Arg>) -> Self
Set the arguments that will be used when launching the node. Override the default_args of the chain context.
Sourcepub fn with_resources(
self,
f: impl FnOnce(ResourcesBuilder) -> ResourcesBuilder,
) -> Self
pub fn with_resources( self, f: impl FnOnce(ResourcesBuilder) -> ResourcesBuilder, ) -> Self
Set the resources limits what will be used for the node (only podman/k8s). Override the default.
Sourcepub fn with_env(self, env: Vec<impl Into<EnvVar>>) -> Self
pub fn with_env(self, env: Vec<impl Into<EnvVar>>) -> Self
Set the node environment variables that will be used when launched. Override the default.
Sourcepub fn with_rpc_port(self, rpc_port: Port) -> Self
pub fn with_rpc_port(self, rpc_port: Port) -> Self
Set the RPC port that will be exposed. Uniqueness across config will be checked.
Sourcepub fn with_mode(self, mode: JamNodeMode) -> Self
pub fn with_mode(self, mode: JamNodeMode) -> Self
Set the Mode of the node.
Sourcepub fn with_telemetry_endpoint(self, tel_endpoint: impl Into<String>) -> Self
pub fn with_telemetry_endpoint(self, tel_endpoint: impl Into<String>) -> Self
Set the Mode of the node.
Sourcepub fn build(self) -> Result<JamNodeConfig, (String, Vec<Error>)>
pub fn build(self) -> Result<JamNodeConfig, (String, Vec<Error>)>
Seals the builder and returns a JamNodeConfig if there are no validation errors, else returns errors.