pub struct ResourcesBuilder { /* private fields */ }Expand description
A resources builder, used to build a Resources declaratively with fields validation.
Implementations
Sourceimpl ResourcesBuilder
impl ResourcesBuilder
pub fn new() -> ResourcesBuilder
Sourcepub fn with_request_memory<T>(self, quantity: T) -> Self
pub fn with_request_memory<T>(self, quantity: T) -> Self
Set the requested memory for a pod. This is the minimum memory allocated for a pod.
Sourcepub fn with_request_cpu<T>(self, quantity: T) -> Self
pub fn with_request_cpu<T>(self, quantity: T) -> Self
Set the requested CPU limit for a pod. This is the minimum CPU allocated for a pod.
Sourcepub fn with_limit_memory<T>(self, quantity: T) -> Self
pub fn with_limit_memory<T>(self, quantity: T) -> Self
Set the overall memory limit for a pod. This is the maximum memory threshold for a pod.
Sourcepub fn with_limit_cpu<T>(self, quantity: T) -> Self
pub fn with_limit_cpu<T>(self, quantity: T) -> Self
Set the overall CPU limit for a pod. This is the maximum CPU threshold for a pod.