pub struct JamchainConfigBuilder<State> { /* private fields */ }Expand description
A relay chain configuration builder, used to build a JamchainConfig declaratively with fields validation.
Implementations
Sourceimpl JamchainConfigBuilder<Initial>
impl JamchainConfigBuilder<Initial>
pub fn new( validation_context: Rc<RefCell<ValidationContext>>, ) -> JamchainConfigBuilder<Initial>
Sourceimpl JamchainConfigBuilder<WithId>
impl JamchainConfigBuilder<WithId>
Sourcepub fn with_default_command<T>(self, command: T) -> Self
pub fn with_default_command<T>(self, command: T) -> Self
Set the default command used for nodes. Can be overridden.
Sourcepub fn with_default_image<T>(self, image: T) -> Self
pub fn with_default_image<T>(self, image: T) -> Self
Set the default container image used for nodes. Can be overridden.
Sourcepub fn with_default_resources(
self,
f: impl FnOnce(ResourcesBuilder) -> ResourcesBuilder,
) -> Self
pub fn with_default_resources( self, f: impl FnOnce(ResourcesBuilder) -> ResourcesBuilder, ) -> Self
Set the default resources limits used for nodes. Can be overridden.
Sourcepub fn with_default_args(self, args: Vec<Arg>) -> Self
pub fn with_default_args(self, args: Vec<Arg>) -> Self
Set the default arguments that will be used to execute the node command. Can be overridden.
Sourcepub fn with_chain_spec_path(self, location: impl Into<AssetLocation>) -> Self
pub fn with_chain_spec_path(self, location: impl Into<AssetLocation>) -> Self
Set the location of a pre-existing chain specification for the chain.
Sourcepub fn with_chain_spec_command<T>(self, command: T) -> Self
pub fn with_chain_spec_command<T>(self, command: T) -> Self
Set the command that generates the chain spec, when it is not the node binary itself.
Only the command is used: the orchestrator appends gen-spec <config> <spec> itself.
Sourcepub fn with_genesis_overrides(self, genesis_overrides: impl Into<Value>) -> Self
pub fn with_genesis_overrides(self, genesis_overrides: impl Into<Value>) -> Self
Set the genesis overrides: a JSON object merged into the config gen-spec reads, on top
of the generated id and genesis_validators. Its keys are gen-spec’s business.
Sourcepub fn with_corevm_monitor_command<T>(self, command: T) -> Self
pub fn with_corevm_monitor_command<T>(self, command: T) -> Self
Set the command used for corevm monitor.
Sourcepub fn with_corevm_builder_command<T>(self, command: T) -> Self
pub fn with_corevm_builder_command<T>(self, command: T) -> Self
Set the command used for corevm builder.
Sourcepub fn with_validator(
self,
f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>,
) -> JamchainConfigBuilder<WithAtLeastOneNode>
pub fn with_validator( self, f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>, ) -> JamchainConfigBuilder<WithAtLeastOneNode>
Add a new validator node using a nested JamNodeConfigBuilder.
The node will be configured as a validator (authority).
Sourcepub fn with_ordinary(
self,
f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>,
) -> JamchainConfigBuilder<WithAtLeastOneNode>
pub fn with_ordinary( self, f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>, ) -> JamchainConfigBuilder<WithAtLeastOneNode>
Add a new ordinary node using a nested JamNodeConfigBuilder.
Sourcepub fn with_proxy(
self,
f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>,
) -> JamchainConfigBuilder<WithAtLeastOneNode>
pub fn with_proxy( self, f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>, ) -> JamchainConfigBuilder<WithAtLeastOneNode>
Add a new proxy node using a nested JamNodeConfigBuilder.
Sourceimpl JamchainConfigBuilder<WithAtLeastOneNode>
impl JamchainConfigBuilder<WithAtLeastOneNode>
Sourcepub fn with_genesis_overrides(self, genesis_overrides: impl Into<Value>) -> Self
pub fn with_genesis_overrides(self, genesis_overrides: impl Into<Value>) -> Self
Set the genesis overrides: a JSON object merged into the config gen-spec reads, on top
of the generated id and genesis_validators. Its keys are gen-spec’s business.
Sourcepub fn with_validator(
self,
f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>,
) -> JamchainConfigBuilder<WithAtLeastOneNode>
pub fn with_validator( self, f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>, ) -> JamchainConfigBuilder<WithAtLeastOneNode>
Add a new validator node using a nested JamNodeConfigBuilder.
The node will be configured as a validator (authority).
Sourcepub fn with_ordinary(
self,
f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>,
) -> JamchainConfigBuilder<WithAtLeastOneNode>
pub fn with_ordinary( self, f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>, ) -> JamchainConfigBuilder<WithAtLeastOneNode>
Add a new ordinary node using a nested JamNodeConfigBuilder.
Sourcepub fn with_proxy(
self,
f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>,
) -> JamchainConfigBuilder<WithAtLeastOneNode>
pub fn with_proxy( self, f: impl FnOnce(JamNodeConfigBuilder<Initial>) -> JamNodeConfigBuilder<Buildable>, ) -> JamchainConfigBuilder<WithAtLeastOneNode>
Add a new proxy node using a nested JamNodeConfigBuilder.
Sourcepub fn build(self) -> Result<JamchainConfig, Vec<Error>>
pub fn build(self) -> Result<JamchainConfig, Vec<Error>>
Seals the builder and returns a JamchainConfig if there are no validation errors, else returns errors.