pub struct ParachainConfig { /* private fields */ }Expand description
A parachain configuration, composed of collators and fine-grained configuration options.
Implementations
Sourceimpl ParachainConfig
impl ParachainConfig
Sourcepub fn registration_strategy(&self) -> Option<&RegistrationStrategy>
pub fn registration_strategy(&self) -> Option<&RegistrationStrategy>
The registration strategy for the parachain.
Sourcepub fn onboard_as_parachain(&self) -> bool
pub fn onboard_as_parachain(&self) -> bool
Whether the parachain should be onboarded or stay a parathread
Sourcepub fn num_cores(&self) -> Option<u32>
pub fn num_cores(&self) -> Option<u32>
Number of cores to assign (1 assigned autatically at genesis)
Sourcepub fn initial_balance(&self) -> u128
pub fn initial_balance(&self) -> u128
The initial balance of the parachain account.
Sourcepub fn default_command(&self) -> Option<&Command>
pub fn default_command(&self) -> Option<&Command>
The default command used for collators.
Sourcepub fn default_image(&self) -> Option<&Image>
pub fn default_image(&self) -> Option<&Image>
The default container image used for collators.
Sourcepub fn default_resources(&self) -> Option<&Resources>
pub fn default_resources(&self) -> Option<&Resources>
The default resources limits used for collators.
Sourcepub fn default_db_snapshot(&self) -> Option<&AssetLocation>
pub fn default_db_snapshot(&self) -> Option<&AssetLocation>
The default database snapshot location that will be used for state.
Sourcepub fn default_args(&self) -> Vec<&Arg>
pub fn default_args(&self) -> Vec<&Arg>
The default arguments that will be used to execute the collator command.
Sourcepub fn genesis_wasm_path(&self) -> Option<&AssetLocation>
pub fn genesis_wasm_path(&self) -> Option<&AssetLocation>
The location of a pre-existing genesis WASM runtime blob of the parachain.
Sourcepub fn genesis_wasm_generator(&self) -> Option<&Command>
pub fn genesis_wasm_generator(&self) -> Option<&Command>
The generator command used to create the genesis WASM runtime blob of the parachain.
Sourcepub fn genesis_state_path(&self) -> Option<&AssetLocation>
pub fn genesis_state_path(&self) -> Option<&AssetLocation>
The location of a pre-existing genesis state of the parachain.
Sourcepub fn genesis_state_generator(&self) -> Option<&CommandWithCustomArgs>
pub fn genesis_state_generator(&self) -> Option<&CommandWithCustomArgs>
The generator command used to create the genesis state of the parachain.
Sourcepub fn genesis_overrides(&self) -> Option<&Value>
pub fn genesis_overrides(&self) -> Option<&Value>
The genesis overrides as a JSON value.
Sourcepub fn chain_spec_path(&self) -> Option<&AssetLocation>
pub fn chain_spec_path(&self) -> Option<&AssetLocation>
The location of a pre-existing chain specification for the parachain.
Sourcepub fn chain_spec_command(&self) -> Option<&str>
pub fn chain_spec_command(&self) -> Option<&str>
The full template command to genera the chain-spec
Sourcepub fn chain_spec_command_is_local(&self) -> bool
pub fn chain_spec_command_is_local(&self) -> bool
Does the chain_spec_command needs to be run locally
Sourcepub fn chain_spec_command_output_path(&self) -> Option<&str>
pub fn chain_spec_command_output_path(&self) -> Option<&str>
The file where the chain_spec_command will write the chain-spec into.
Defaults to /dev/stdout.
Sourcepub fn post_process_script(&self) -> Option<&str>
pub fn post_process_script(&self) -> Option<&str>
Optional post-process script to run after chain-spec generation for this parachain.
Sourcepub fn is_cumulus_based(&self) -> bool
pub fn is_cumulus_based(&self) -> bool
Whether the parachain is based on cumulus.
Sourcepub fn is_evm_based(&self) -> bool
pub fn is_evm_based(&self) -> bool
Whether the parachain is evm based (e.g frontier).
Sourcepub fn bootnodes_addresses(&self) -> Vec<&Multiaddr>
pub fn bootnodes_addresses(&self) -> Vec<&Multiaddr>
The bootnodes addresses the collators will connect to.
Sourcepub fn no_default_bootnodes(&self) -> bool
pub fn no_default_bootnodes(&self) -> bool
Whether to not automatically assign a bootnode role if none of the nodes are marked as bootnodes.
Sourcepub fn collators(&self) -> Vec<&NodeConfig>
pub fn collators(&self) -> Vec<&NodeConfig>
The collators of the parachain.
Sourcepub fn group_collators_configs(&self) -> Vec<&GroupNodeConfig>
pub fn group_collators_configs(&self) -> Vec<&GroupNodeConfig>
The grouped collators of the parachain.
Sourcepub fn wasm_override(&self) -> Option<&AssetLocation>
pub fn wasm_override(&self) -> Option<&AssetLocation>
The location of a wasm runtime to override in the chain-spec.
Sourcepub fn raw_spec_override(&self) -> Option<&JsonOverrides>
pub fn raw_spec_override(&self) -> Option<&JsonOverrides>
The location of a file or inline json to override raw chain-spec.
Sourcepub fn chain_spec_runtime(&self) -> Option<&ChainSpecRuntime>
pub fn chain_spec_runtime(&self) -> Option<&ChainSpecRuntime>
The location of runtime to use by chain-spec builder lib (from sc-chain-spec crate)