pub struct RelaychainConfig { /* private fields */ }Expand description
A relay chain configuration, composed of nodes and fine-grained configuration options.
Implementations
Sourceimpl RelaychainConfig
impl RelaychainConfig
Sourcepub fn default_command(&self) -> Option<&Command>
pub fn default_command(&self) -> Option<&Command>
The default command used for nodes.
Sourcepub fn default_image(&self) -> Option<&Image>
pub fn default_image(&self) -> Option<&Image>
The default container image used for nodes.
Sourcepub fn default_resources(&self) -> Option<&Resources>
pub fn default_resources(&self) -> Option<&Resources>
The default resources limits used for nodes.
Sourcepub fn default_db_snapshot(&self) -> Option<&AssetLocation>
pub fn default_db_snapshot(&self) -> Option<&AssetLocation>
The default database snapshot location that will be used for state.
Sourcepub fn default_args(&self) -> Vec<&Arg>
pub fn default_args(&self) -> Vec<&Arg>
The default arguments that will be used to launch the node command.
Sourcepub fn chain_spec_path(&self) -> Option<&AssetLocation>
pub fn chain_spec_path(&self) -> Option<&AssetLocation>
The location of an pre-existing chain specification for the relay chain.
Sourcepub fn wasm_override(&self) -> Option<&AssetLocation>
pub fn wasm_override(&self) -> Option<&AssetLocation>
The location of a wasm runtime to override in the chain-spec.
Sourcepub fn chain_spec_command(&self) -> Option<&str>
pub fn chain_spec_command(&self) -> Option<&str>
The full template command to genera the chain-spec
Sourcepub fn chain_spec_command_is_local(&self) -> bool
pub fn chain_spec_command_is_local(&self) -> bool
Does the chain_spec_command needs to be run locally
pub fn override_session_0(&self) -> bool
Sourcepub fn chain_spec_command_output_path(&self) -> Option<&str>
pub fn chain_spec_command_output_path(&self) -> Option<&str>
The file where the chain_spec_command will write the chain-spec into.
Defaults to /dev/stdout.
Sourcepub fn random_nominators_count(&self) -> Option<u32>
pub fn random_nominators_count(&self) -> Option<u32>
The number of random nominators to create for chains using staking, this is used in tandem with max_nominations to simulate the amount of nominators and nominations.
Sourcepub fn max_nominations(&self) -> Option<u8>
pub fn max_nominations(&self) -> Option<u8>
The maximum number of nominations to create per nominator.
Sourcepub fn runtime_genesis_patch(&self) -> Option<&Value>
pub fn runtime_genesis_patch(&self) -> Option<&Value>
The genesis overrides as a JSON value.
Sourcepub fn nodes(&self) -> Vec<&NodeConfig>
pub fn nodes(&self) -> Vec<&NodeConfig>
The nodes of the relay chain.
Sourcepub fn group_node_configs(&self) -> Vec<&GroupNodeConfig>
pub fn group_node_configs(&self) -> Vec<&GroupNodeConfig>
The group nodes of the relay chain.
Sourcepub fn raw_spec_override(&self) -> Option<&JsonOverrides>
pub fn raw_spec_override(&self) -> Option<&JsonOverrides>
The location of a file or inline json to override raw chain-spec.
Sourcepub fn post_process_script(&self) -> Option<&str>
pub fn post_process_script(&self) -> Option<&str>
Optional post-process script to run after chain-spec generation for this relaychain.
Sourcepub fn chain_spec_runtime(&self) -> Option<&ChainSpecRuntime>
pub fn chain_spec_runtime(&self) -> Option<&ChainSpecRuntime>
The location of runtime to use by chain-spec builder lib (from sc-chain-spec crate)