pub struct ParachainConfigBuilder<S, C> { /* private fields */ }Expand description
A parachain configuration builder, used to build a ParachainConfig declaratively with fields validation.
Implementations
Sourceimpl<A, C> ParachainConfigBuilder<A, C>
impl<A, C> ParachainConfigBuilder<A, C>
Sourcepub fn with_post_process_script(self, script: impl Into<String>) -> Self
pub fn with_post_process_script(self, script: impl Into<String>) -> Self
Set an optional post-process script to run after chain-spec generation for this parachain.
Sourceimpl ParachainConfigBuilder<Initial, Bootstrap>
impl ParachainConfigBuilder<Initial, Bootstrap>
Sourcepub fn new(
validation_context: Rc<RefCell<ValidationContext>>,
) -> ParachainConfigBuilder<Initial, Bootstrap>
pub fn new( validation_context: Rc<RefCell<ValidationContext>>, ) -> ParachainConfigBuilder<Initial, Bootstrap>
Instantiate a new builder that can be used to build a ParachainConfig during the bootstrap phase.
Sourceimpl ParachainConfigBuilder<WithId, Bootstrap>
impl ParachainConfigBuilder<WithId, Bootstrap>
Sourcepub fn with_registration_strategy(self, strategy: RegistrationStrategy) -> Self
pub fn with_registration_strategy(self, strategy: RegistrationStrategy) -> Self
Set the registration strategy for the parachain, could be Manual (no registered by zombienet) or automatic using an extrinsic or in genesis.
Sourceimpl ParachainConfigBuilder<WithId, Running>
impl ParachainConfigBuilder<WithId, Running>
Sourcepub fn with_registration_strategy(self, strategy: RegistrationStrategy) -> Self
pub fn with_registration_strategy(self, strategy: RegistrationStrategy) -> Self
Set the registration strategy for the parachain, could be Manual (no registered by zombienet) or automatic
Using an extrinsic. Genesis option is not allowed in Running context.
Sourceimpl ParachainConfigBuilder<Initial, Running>
impl ParachainConfigBuilder<Initial, Running>
Sourcepub fn new_with_running(
validation_context: Rc<RefCell<ValidationContext>>,
) -> ParachainConfigBuilder<Initial, Running>
pub fn new_with_running( validation_context: Rc<RefCell<ValidationContext>>, ) -> ParachainConfigBuilder<Initial, Running>
Start a new builder in the context of a running network
Sourceimpl<C: Context> ParachainConfigBuilder<Initial, C>
impl<C: Context> ParachainConfigBuilder<Initial, C>
Sourcepub fn with_id(self, id: u32) -> ParachainConfigBuilder<WithId, C>
pub fn with_id(self, id: u32) -> ParachainConfigBuilder<WithId, C>
Set the parachain ID and the unique_id (with the suffix <para_id>-x if the id is already used)
Sourceimpl<C: Context> ParachainConfigBuilder<WithId, C>
impl<C: Context> ParachainConfigBuilder<WithId, C>
Sourcepub fn with_chain<T>(self, chain: T) -> Self
pub fn with_chain<T>(self, chain: T) -> Self
Set the chain name (e.g. rococo-local).
Use None, if you are running adder-collator or undying-collator).
Sourcepub fn onboard_as_parachain(self, choice: bool) -> Self
pub fn onboard_as_parachain(self, choice: bool) -> Self
Set whether the parachain should be onboarded or stay a parathread. Default is true.
Sourcepub fn with_num_cores(self, cores: u32) -> Self
pub fn with_num_cores(self, cores: u32) -> Self
Set the number of cores to assign at genesis NOTE: 1 is the default
Sourcepub fn with_initial_balance(self, initial_balance: u128) -> Self
pub fn with_initial_balance(self, initial_balance: u128) -> Self
Set the initial balance of the parachain account.
Sourcepub fn with_default_command<T>(self, command: T) -> Self
pub fn with_default_command<T>(self, command: T) -> Self
Set the default command used for collators. Can be overridden.
Sourcepub fn with_default_image<T>(self, image: T) -> Self
pub fn with_default_image<T>(self, image: T) -> Self
Set the default container image used for collators. Can be overridden.
Sourcepub fn with_default_resources(
self,
f: impl FnOnce(ResourcesBuilder) -> ResourcesBuilder,
) -> Self
pub fn with_default_resources( self, f: impl FnOnce(ResourcesBuilder) -> ResourcesBuilder, ) -> Self
Set the default resources limits used for collators. Can be overridden.
Sourcepub fn with_default_db_snapshot(
self,
location: impl Into<AssetLocation>,
) -> Self
pub fn with_default_db_snapshot( self, location: impl Into<AssetLocation>, ) -> Self
Set the default database snapshot location that will be used for state. Can be overridden.
Sourcepub fn with_default_args(self, args: Vec<Arg>) -> Self
pub fn with_default_args(self, args: Vec<Arg>) -> Self
Set the default arguments that will be used to execute the collator command. Can be overridden.
Sourcepub fn with_genesis_wasm_path(self, location: impl Into<AssetLocation>) -> Self
pub fn with_genesis_wasm_path(self, location: impl Into<AssetLocation>) -> Self
Set the location of a pre-existing genesis WASM runtime blob of the parachain.
Sourcepub fn with_genesis_wasm_generator<T>(self, command: T) -> Self
pub fn with_genesis_wasm_generator<T>(self, command: T) -> Self
Set the generator command used to create the genesis WASM runtime blob of the parachain.
Sourcepub fn with_genesis_state_path(self, location: impl Into<AssetLocation>) -> Self
pub fn with_genesis_state_path(self, location: impl Into<AssetLocation>) -> Self
Set the location of a pre-existing genesis state of the parachain.
Sourcepub fn with_genesis_state_generator<T>(self, command: T) -> Self
pub fn with_genesis_state_generator<T>(self, command: T) -> Self
Set the generator command used to create the genesis state of the parachain.
Sourcepub fn with_genesis_overrides(self, genesis_overrides: impl Into<Value>) -> Self
pub fn with_genesis_overrides(self, genesis_overrides: impl Into<Value>) -> Self
Set the genesis overrides as a JSON object.
Sourcepub fn with_chain_spec_path(self, location: impl Into<AssetLocation>) -> Self
pub fn with_chain_spec_path(self, location: impl Into<AssetLocation>) -> Self
Set the location of a pre-existing chain specification for the parachain.
Sourcepub fn with_chain_spec_command(self, cmd_template: impl Into<String>) -> Self
pub fn with_chain_spec_command(self, cmd_template: impl Into<String>) -> Self
Set the chain-spec command template for the relay chain.
Sourcepub fn with_chain_spec_runtime(
self,
location: impl Into<AssetLocation>,
preset: Option<&str>,
) -> Self
pub fn with_chain_spec_runtime( self, location: impl Into<AssetLocation>, preset: Option<&str>, ) -> Self
Set the runtime path to use for generating the chain-spec and an optiona preset.
If the preset is not set, we will try to match [local_testnet, development, dev]
with the available ones and fallback to the default configuration as last option.
Sourcepub fn with_wasm_override(self, location: impl Into<AssetLocation>) -> Self
pub fn with_wasm_override(self, location: impl Into<AssetLocation>) -> Self
Set the location of a wasm to override the chain-spec.
Sourcepub fn chain_spec_command_is_local(self, choice: bool) -> Self
pub fn chain_spec_command_is_local(self, choice: bool) -> Self
Set if the chain-spec command needs to be run locally or not (false by default)
Sourcepub fn with_chain_spec_command_output_path(self, output_path: &str) -> Self
pub fn with_chain_spec_command_output_path(self, output_path: &str) -> Self
Set the output path for the chain-spec command.
Sourcepub fn cumulus_based(self, choice: bool) -> Self
pub fn cumulus_based(self, choice: bool) -> Self
Set whether the parachain is based on cumulus (true in a majority of case, except adder or undying collators).
Sourcepub fn evm_based(self, choice: bool) -> Self
pub fn evm_based(self, choice: bool) -> Self
Set whether the parachain is evm based (e.g frontier /evm template)
Sourcepub fn with_raw_bootnodes_addresses<T>(
self,
bootnodes_addresses: Vec<T>,
) -> Self
pub fn with_raw_bootnodes_addresses<T>( self, bootnodes_addresses: Vec<T>, ) -> Self
Set the bootnodes addresses the collators will connect to.
Note: Bootnode address replacements are NOT supported here.
Only arguments (args) support dynamic replacements. Bootnode addresses must be a valid address.
Sourcepub fn without_default_bootnodes(self) -> Self
pub fn without_default_bootnodes(self) -> Self
Do not assign a bootnode role automatically if no nodes are marked as bootnodes.
Sourcepub fn with_collator(
self,
f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>,
) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
pub fn with_collator( self, f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>, ) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
Add a new collator using a nested NodeConfigBuilder.
Sourcepub fn with_fullnode(
self,
f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>,
) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
pub fn with_fullnode( self, f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>, ) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
Add a new full node using a nested NodeConfigBuilder.
The node will be configured as a full node (non-validator).
Sourcepub fn with_node(
self,
f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>,
) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
👎Deprecated since 0.4.0: Use with_collator() for collator nodes or with_fullnode() for full nodes instead
pub fn with_node( self, f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>, ) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
with_collator() for collator nodes or with_fullnode() for full nodes insteadAdd a new node using a nested NodeConfigBuilder.
Deprecated: Use [with_collator] for collator nodes or [with_fullnode] for full nodes instead.
Sourcepub fn with_collator_group(
self,
f: impl FnOnce(GroupNodeConfigBuilder<Initial>) -> GroupNodeConfigBuilder<Buildable>,
) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
pub fn with_collator_group( self, f: impl FnOnce(GroupNodeConfigBuilder<Initial>) -> GroupNodeConfigBuilder<Buildable>, ) -> ParachainConfigBuilder<WithAtLeastOneCollator, C>
Add a new collator group using a nested GroupNodeConfigBuilder.
Sourcepub fn with_raw_spec_override(self, overrides: impl Into<JsonOverrides>) -> Self
pub fn with_raw_spec_override(self, overrides: impl Into<JsonOverrides>) -> Self
Set the location or inline value of json to override the raw chain-spec.
Sourceimpl<C: Context> ParachainConfigBuilder<WithAtLeastOneCollator, C>
impl<C: Context> ParachainConfigBuilder<WithAtLeastOneCollator, C>
Sourcepub fn with_collator(
self,
f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>,
) -> Self
pub fn with_collator( self, f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>, ) -> Self
Add a new collator using a nested NodeConfigBuilder.
Sourcepub fn with_fullnode(
self,
f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>,
) -> Self
pub fn with_fullnode( self, f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>, ) -> Self
Add a new full node using a nested NodeConfigBuilder.
The node will be configured as a full node (non-validator).
Sourcepub fn with_node(
self,
f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>,
) -> Self
👎Deprecated since 0.4.0: Use with_collator() for collator nodes or with_fullnode() for full nodes instead
pub fn with_node( self, f: impl FnOnce(NodeConfigBuilder<Initial>) -> NodeConfigBuilder<Buildable>, ) -> Self
with_collator() for collator nodes or with_fullnode() for full nodes insteadAdd a new node using a nested NodeConfigBuilder.
Deprecated: Use [with_collator] for collator nodes or [with_fullnode] for full nodes instead.
Sourcepub fn with_collator_group(
self,
f: impl FnOnce(GroupNodeConfigBuilder<Initial>) -> GroupNodeConfigBuilder<Buildable>,
) -> Self
pub fn with_collator_group( self, f: impl FnOnce(GroupNodeConfigBuilder<Initial>) -> GroupNodeConfigBuilder<Buildable>, ) -> Self
Add a new collator group using a nested GroupNodeConfigBuilder.
Sourcepub fn build(self) -> Result<ParachainConfig, Vec<Error>>
pub fn build(self) -> Result<ParachainConfig, Vec<Error>>
Seals the builder and returns a ParachainConfig if there are no validation errors, else returns errors.